diff --git a/smack-im/src/main/java/org/jivesoftware/smack/roster/rosterstore/RosterStore.java b/smack-im/src/main/java/org/jivesoftware/smack/roster/rosterstore/RosterStore.java
index b9c7b30b1..ab7e39649 100644
--- a/smack-im/src/main/java/org/jivesoftware/smack/roster/rosterstore/RosterStore.java
+++ b/smack-im/src/main/java/org/jivesoftware/smack/roster/rosterstore/RosterStore.java
@@ -17,6 +17,7 @@
package org.jivesoftware.smack.roster.rosterstore;
import java.util.Collection;
+import java.util.List;
import org.jivesoftware.smack.roster.packet.RosterPacket;
import org.jxmpp.jid.Jid;
@@ -29,10 +30,12 @@ import org.jxmpp.jid.Jid;
public interface RosterStore {
/**
* This method returns a collection of all roster items contained in this store.
* @return List of {@link org.jivesoftware.smack.roster.RosterEntry}
is returned.
+ *
+ * @return List of {@link org.jivesoftware.smack.roster.RosterEntry} or null
.
*/
- public Collection getEntries();
+ public List getEntries();
+
/**
* This method returns the roster item in this store for the given JID.
* @param bareJid The bare JID of the RosterEntry
@@ -29,10 +30,12 @@ import org.jxmpp.jid.Jid;
public interface RosterStore {
/**
- * This method returns a collection of all roster items contained in this store.
- * @return List of {@link org.jivesoftware.smack.roster.RosterEntry}
+ * This method returns a list of all roster items contained in this store. If there was an error while loading the store, then null
is returned.